#
# spec file for package gsmartcontrol
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gsmartcontrol
Version:        1.1.4
Release:        1.11
Summary:        Hard Disk Health Inspection Tool
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Hardware/Other
URL:            http://gsmartcontrol.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  polkit
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.4
BuildRequires:  pkgconfig(libpcre)
Requires:       pcre
Requires:       polkit
Requires:       smartmontools >= 5.43
Recommends:     xdg-utils

%description
GSmartControl is a graphical user interface for smartctl, which is a tool for
querying and controlling SMART (Self-Monitoring, Analysis, and Reporting
Technology) data in hard disk drives. It allows inspecting the drive's
SMART data to determine its health, as well as run various tests on it.

%prep
%setup -q
#rpmlintrc
sed -i -e 's|\/usr\/bin\/env bash|\/usr\/bin\/bash|g' data/gsmartcontrol-root.in

%build
%configure --docdir=%{_defaultdocdir}/%{name} --enable-optimize-options=auto
%make_build

%install
%make_install
%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}
rm %{buildroot}%{_defaultdocdir}/%{name}/LICENSE_*.txt

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc %{_defaultdocdir}/%{name}
%license COPYING LICENSE_*.txt
%{_sbindir}/%{name}
%{_bindir}/%{name}-root
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-root.1%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/polkit-1/actions/org.gsmartcontrol.policy

%changelog
* Tue Aug  9 2022 ecsos <ecsos@opensuse.org>
- Update to version 1.1.4
  - Fixed a crash when trying to render main window icons which
    have incomplete data;
    this fixes a rare crash when scanning devices (#13).
  - Fixed rendering compatibility issues with newer GTK3 versions.
  - Fixed build system conflict with C++20 version header (#14).
  - Fixed "Running command ..." dialog floating above windows of
    other applications (#17).
  - Fixed a crash when system locale is set to invalid locale.
  - Support Finnish decimal separator
    (backported from the Debian package) (#23).
  - Set LC_NUMERIC=C for smartctl process to avoid locale-dependent
    number formatting (#23).
  - Fixed printing all GTK messages as warnings; the messages are
    sorted by severity now.
  - Add current time to default filename in Save Output dialog.
  - Support macos stat command in file2csource.sh.
  - Fixed a few typos (backported from the Debian package).
  - Windows port now uses Adwaita theme due to issues with win32 theme.
  - Windows port is dpi-aware now.
- Run spec-cleaner.
* Sun Nov 12 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.3
  + Fixed gsmartcontrol-root not launching if GDK_* variables are
    not set.
- Version 1.1.2
  + Fixed gsmartcontrol-root not passing GDK_SCALE and
    GDK_DPI_SCALE variables to gsmartcontrol when using PolKit.
  + Fixed blurriness of icons in the main window with GDK_SCALE=2.
  + Tweaked the main window interface.
  + Windows: Show volume labels beside drive letters in icon
    tooltips.
* Mon Oct  2 2017 jengelh@inai.de
- Do not use install-strip so that debuginfo stays usable.
* Wed Sep 27 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.1
  + Windows: Use Adwaita GTK+ theme for systems which support
    Classic Windows theme, since the default win32 GTK+ theme is
    broken in it; this includes Windows 7 and Windows Server.
  + Statistics entry values are formatted with commas for
    readability.
  + Moved help information to website.
* Mon Sep 11 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.0
  + New Statistics, Temperature Log, Error Recovery, Physical and
    Directory tabs.
  + General tab shows non-SMART device settings as well.
  + Attributes tab shows entries in "brief" format.
  + Error Log tab shows Extended error log by default (if
    supported).
  + Self-Test Log tab now shows Extended self-test log by default
    (if supported).
  + GSmartControl now uses "-x" equivalent for retrieving data (as
    upposed to "-a"); loading "-x" outputs as virtual drives is
    also supported.
  + Implemented ability to copy rows in CSV format from Attribute,
    Statistics and Self-Test Log tables.
  + Implemented "Update Drive Database" functionality.
  + Windows: Drive letters are shown for each drive.
  + Scan time is shown under virtual drive icons.
  + Polkit is supported with gsmartcontrol-root script now.
  + Pcrecpp is no longer bundled, use system-installed one instead.
  + Smartmontools version 5.43 is required at runtime.
  + Other minor improvements and fixes.
* Mon Jul 24 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.2
  + Fixed incomplete capturing of smartctl output under Windows.
  + Added missing icons under Windows.
  + Fixed being able to turn on AODC even if unsupported.
* Mon Jun 19 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.1
  + Fixed compilation under macOS.
  + Fixed compilation under Fedora Rawhide.
  + Don't use -mtune=generic for all targets.
* Fri Jun 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.0
  + Ported to GTK+ 3.
  + Tweaked the user interface a bit.
  + Dropped support for Windows XP, 2000 and 2003 (they are no
    longer supported by GTK+).
  + Fixed detection of newer system-installed smartmontools under
    Windows.
* Tue May 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 0.9.0
  + Implemented (untested) support for Linux-based Areca
    controllers with enclosures.
  + Implemented (untested) support for Windows-based Areca
    controllers (thanks to Richard Kagerer).
  + Implemented (untested) support for Linux-based HP controllers
    with cciss and hpsa/hpahcisr drivers (thanks to
    Fabrice Bacchella).
  + Changes in Preferences no longer fail silently until
    rescan/restart.
  + Better drive detection under Windows after removable drives
    are detached.
  + Windows version is no longer marked as "dpi aware" since it's
    not supported that well.
  + Drive attribute descriptions have been updated (including
    clarifications for SSDs).
  + Added support for SSD-only and HDD-only vendor attributes.
  + Devices having only basic info can be displayed now in the
    info window.
  + Fixed BDRW drive detection (it was detected as a HDD).
  + Other minor improvements.
  + A number of issues have been fixed (including a crash).
* Wed Oct 12 2016 mailaender@opensuse.org
- install licenses
- add missing desktop/icon macros
- recommend xdg-su
* Sun Aug 28 2016 mailaender@opensuse.org
- drop unused and unapplicable gsmartcontrol_parser_crash_fix.diff
* Thu Jun 23 2016 nemysis@openSUSE.org
- Initial package creation
